@@ -1,7 +1,7 @@
 /*
  * version - determine the version of calc
  *
- * Copyright (C) 1999-2007  David I. Bell and Landon Curt Noll
+ * Copyright (C) 1999-2014  David I. Bell and Landon Curt Noll
  *
  * Primary author:  David I. Bell
  *
@@ -19,9 +19,9 @@
  * received a copy with calc; if not, write to Free Software Foundation, Inc.
  * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * @(#) $Revision: 30.12 $
- * @(#) $Id: version.c,v 30.12 2010/09/02 06:36:48 chongo Exp $
- * @(#) $Source: /usr/local/src/cmd/calc/RCS/version.c,v $
+ * @(#) $Revision: 30.31 $
+ * @(#) $Id: version.c,v 30.31 2016/02/22 19:37:21 chongo Exp $
+ * @(#) $Source: /usr/local/src/bin/calc/RCS/version.c,v $
  *
  * Under source code control:	1990/05/22 11:00:58
  * File existed as early as:	1990
@@ -48,8 +48,8 @@ static char *program;
 
 #define MAJOR_VER	2	/* major library version */
 #define MINOR_VER	12	/* minor library version */
-#define MAJOR_PATCH	4	/* major software level under library version */
-#define MINOR_PATCH	2	/* minor software level or 0 if not patched */
+#define MAJOR_PATCH	5	/* major software level under library version */
+#define MINOR_PATCH	4	/* minor software level or 0 if not patched */
 
 
 /*
@@ -73,19 +73,20 @@ STATIC char *stored_version = NULL;	/* version formed if != NULL */
 char *Copyright = "\n"
   "calc - arbitrary precision calculator\n"
   "\n"
-  "@(#) Copyright (C) 2007  David I. Bell, Landon Curt Noll and Ernest Bowen\n"
+  "@(#) Copyright (C) 1999-2014  David I. Bell, Landon Curt Noll "
+  					   "and Ernest Bowen\n"
   "\n"
   "Initial author:  David I. Bell\n"
   "\n"
   "Calc is open software; you can redistribute it and/or modify it under\n"
   "the terms of the version 2.1 of the GNU Lesser General Public License\n"
-  "as published by the Free Software Foundation.\n"
-  "\n"
+  "as published by the Free Software Foundation.\n";
+char *Usability = "\n"
   "Calc is distributed in the hope that it will be useful, but WITHOUT\n"
   "ANY WARRANTY; without even the implied warranty of MERCHANTABILITY\n"
   "or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU Lesser General\n"
-  "Public License for more details.\n"
-  "\n"
+  "Public License for more details.\n";
+char *COPYING_LGPL = "\n"
   "A copy of version 2.1 of the GNU Lesser General Public License is\n"
   "distributed with calc under the filename COPYING-LGPL.  You should have\n"
   "received a copy with calc; if not, write to Free Software Foundation, Inc.\n"
@@ -149,7 +150,6 @@ version(void)
  * This function prints a version string, rpm style:
  *
  *		x.y.z.w-r
- *		x.y.z-r
  *
  * where 'r' comes from the content of the release file.
  */
@@ -183,13 +183,8 @@ print_rpm_version(char *release)
 	/*
 	 * form the version buffer
 	 */
-	if (MINOR_PATCH > 0) {
-		printf("%d.%d.%d.%d-%s\n", calc_major_ver, calc_minor_ver,
-				      calc_major_patch, calc_minor_patch, buf);
-	} else {
-		printf("%d.%d.%d-%s\n", calc_major_ver, calc_minor_ver,
-				     calc_major_patch, buf);
-	}
+	printf("%d.%d.%d.%d-%s\n", calc_major_ver, calc_minor_ver,
+			      calc_major_patch, calc_minor_patch, buf);
 	return;
 }
 
